part of ngx_core.js;
// ignore_for_file: non_constant_identifier_names

/// The base class for all [JavaScript](https://developer.mozilla.org/en-US/docs/Web/JavaScript) objects.
@JS('Object')
class JSObject {

  /// Creates a new object.
  external JSObject([value]);

  /// Copies the values of all enumerable own properties from one or more source objects to a [target] object.
  /// Returns the target object.
  external static dynamic assign(target, [source1, source2, source3, source4, source5, source6, source7]);

  /// Returns a list of a given [object]'s own enumerable property `[key, value]` pairs.
  external static List<List> entries(object);

  /// Freezes an [object]: that is, prevents new properties from being added to it; prevents existing properties from being removed;
  /// and prevents existing properties, or their enumerability, configurability, or writability, from being changed.
  /// Returns the frozen object.
  external static dynamic freeze(object);

  /// Returns a list of all properties (including non-enumerable properties except for those which use `Symbol`)
  /// found directly upon a given [object].
  external static List<String> getOwnPropertyNames(object);

  /// Returns the prototype of the specified [object].
  external static dynamic getPrototypeOf(object);

  /// Determines whether two values are the same value.
  external static bool JS$is(value1, value2);

  /// Returns a value indicating whether an [object] is extensible (whether it can have new properties added to it).
  external static bool isExtensible(object);

  /// Returns a value indicating whether an [object] is frozen.
  external static bool isFrozen(object);

  /// Returns a value indicating whether an [object] is sealed.
  external static bool isSealed(object);

  /// Returns a list of a given [object]'s own enumerable properties.
  external static List<String> keys(object);

  /// Prevents new properties from ever being added to an [object] (i.e. prevents future extensions to the object).
  /// Returns the object being made non-extensible.
  external static dynamic preventExtensions(object);

  /// Seals an [object], preventing new properties from being added to it and marking all existing properties as non-configurable.
  /// Returns the object being sealed.
  external static dynamic seal(object);

  /// Sets the [prototype] of a given [object].
  /// Returns the specified object.
  external static dynamic setPrototypeOf(object, prototype);

  /// Returns a list of a given [object]'s own enumerable property values.
  external static List values(object);
}
