/// Provides helper functions for [JavaScript](https://developer.mozilla.org/en-US/docs/Web/JavaScript) interoperability.
@JS()
library ngx_core.util;

import 'dart:js_util';
import 'dart:typed_data';
import 'package:js/js.dart';
import 'js.dart';

/// The JavaScript object providing the application configuration.
@JS(r'$configuration')
external dynamic get configuration;

/// The JavaScript string providing the application environment.
@JS(r'$environment')
external String get environment;

/// The global namespace object.
@JS('window')
external dynamic get global;

/// Recursively converts the specified JavaScript [value] to a Dart object.
dynamic dartify(value) {
  if (value == null) return null;
  if (value is bool || value is num || value is DateTime || value is String || value is TypedData) return value;
  if (value is List) return value.map(dartify).toList();
  return new Map<String, dynamic>.fromIterable(JSObject.keys(value), value: (key) => dartify(getProperty(value, key)));
}
