import 'dart:js_util';
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';

/// Tests the features of the [JSObject] class.
void main() => group('JSObject', () {
  group('.assign()', () {
    test('should copy the properties from one or more source objects to a target object', () {
      var source1 = jsify({'foo': 'bar'});
      var source2 = jsify({'baz': 'qux'});
      var target = newObject();

      var result = JSObject.assign(target, source1, source2);
      expect(getProperty(result, 'foo'), equals('bar'));
      expect(getProperty(result, 'baz'), equals('qux'));
      expect(result, equals(target));
    });
  });

  group('.entries()', () {
    test("should return the names and values of an object's properties", () {
      var entries = JSObject.entries(jsify({'foo': 'bar', 'baz': 'qux'}));
      expect(entries, hasLength(2));
      expect(entries.first, orderedEquals(['foo', 'bar']));
      expect(entries.last, orderedEquals(['baz', 'qux']));
    });
  });

  group('.is()', () {
    test('should return `true` if two values are the same value', () {
      expect(JSObject.JS$is(null, null), isTrue);
      expect(JSObject.JS$is(123, 123.0), isTrue);
      expect(JSObject.JS$is('foo', 'foo'), isTrue);

      var test = jsify({'a': 1});
      expect(JSObject.JS$is(test, test), isTrue);

      expect(JSObject.JS$is('foo', 'bar'), isFalse);
      expect(JSObject.JS$is(0, -0), isFalse);

      expect(JSObject.JS$is(-0, -0), isTrue);
      expect(JSObject.JS$is(double.NAN, 0/0), isTrue);
    });
  });

  group('.isExtensible()', () {
    test('should return `true` if an object is extensible', () {
      var object = newObject();
      expect(JSObject.isExtensible(object), isTrue);

      JSObject.preventExtensions(object);
      expect(JSObject.isExtensible(object), isFalse);
    });
  });

  group('.isFrozen()', () {
    test('should return `true` if an object is frozen', () {
      var object = newObject();
      expect(JSObject.isFrozen(object), isFalse);

      JSObject.freeze(object);
      expect(JSObject.isFrozen(object), isTrue);
    });
  });

  group('.isSealed()', () {
    test('should return `true` if an object is sealed', () {
      var object = newObject();
      expect(JSObject.isSealed(object), isFalse);

      JSObject.seal(object);
      expect(JSObject.isSealed(object), isTrue);
    });
  });

  group('.keys()', () {
    test("should return the names of an object's properties", () {
      expect(JSObject.keys(jsify({'foo': 'bar', 'baz': 'qux'})), unorderedEquals(['foo', 'baz']));
    });
  });

  group('.values()', () {
    test("should return the values of an object's properties", () {
      expect(JSObject.values(jsify({'foo': 'bar', 'baz': 'qux'})), unorderedEquals(['bar', 'qux']));
    });
  });
});
