import 'dart:js_util';
import 'package:ngx_core/ngx_core.dart';
import 'package:test/test.dart';

/// Tests the features of the `ngx_core.util` library.
void main() {
  group('configuration', () {
    test('should be `null` by default', () {
      expect(configuration, isNull);
    });

    test(r'should return the value of the `window.$config` property', () {
      var object = jsify({'foo': 'bar'});
      setProperty(global, r'$configuration', object);
      expect(configuration, equals(object));
    });
  });

  group('environment', () {
    test('should be `null` by default', () {
      expect(environment, isNull);
    });

    test(r'should return the value of the `window.$environment` property', () {
      setProperty(global, r'$environment', 'fooBar');
      expect(environment, equals('fooBar'));
    });
  });

  group('dartify()', () {
    test('should leave unchanged the supported Dart types', () {
      var now = new DateTime.now();
      expect(dartify(null), isNull);
      expect(dartify(false), isFalse);
      expect(dartify(123), equals(123));
      expect(dartify(-123.456), equals(-123.456));
      expect(dartify(now), equals(now));
      expect(dartify('foo'), equals('foo'));
    });

    test('should convert the supported JavaScript types', () {
      var array = jsify(['foo']);
      expect(dartify(array), allOf(isList, hasLength(1), contains('foo')));

      var object = jsify({'foo': 'bar'});
      expect(dartify(object), allOf(isMap, hasLength(1), containsPair('foo', 'bar')));
    });
  });
}
